# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'dls_powerpmacanalyse/formLogin.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtWidgets


class Ui_Login(object):
    def setupUi(self, Login):
        Login.setObjectName("Login")
        Login.resize(314, 145)
        self.widget = QtWidgets.QWidget(Login)
        self.widget.setGeometry(QtCore.QRect(51, 11, 215, 80))
        self.widget.setObjectName("widget")
        self.gridLayout = QtWidgets.QGridLayout(self.widget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.labelUsername = QtWidgets.QLabel(self.widget)
        self.labelUsername.setObjectName("labelUsername")
        self.gridLayout.addWidget(self.labelUsername, 0, 0, 1, 1)
        self.lneUsername = QtWidgets.QLineEdit(self.widget)
        self.lneUsername.setText("")
        self.lneUsername.setObjectName("lneUsername")
        self.gridLayout.addWidget(self.lneUsername, 0, 1, 1, 1)
        self.labelPassword = QtWidgets.QLabel(self.widget)
        self.labelPassword.setObjectName("labelPassword")
        self.gridLayout.addWidget(self.labelPassword, 1, 0, 1, 1)
        self.lnePassword = QtWidgets.QLineEdit(self.widget)
        self.lnePassword.setObjectName("lnePassword")
        self.gridLayout.addWidget(self.lnePassword, 1, 1, 1, 1)
        self.widget1 = QtWidgets.QWidget(Login)
        self.widget1.setGeometry(QtCore.QRect(65, 100, 184, 38))
        self.widget1.setObjectName("widget1")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget1)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnCancel = QtWidgets.QPushButton(self.widget1)
        self.btnCancel.setObjectName("btnCancel")
        self.horizontalLayout.addWidget(self.btnCancel)
        self.btnOK = QtWidgets.QPushButton(self.widget1)
        self.btnOK.setObjectName("btnOK")
        self.horizontalLayout.addWidget(self.btnOK)

        self.retranslateUi(Login)
        self.btnCancel.clicked.connect(Login.clickedCancel)
        self.btnOK.clicked.connect(Login.clickedOK)
        QtCore.QMetaObject.connectSlotsByName(Login)
        Login.setTabOrder(self.lneUsername, self.lnePassword)
        Login.setTabOrder(self.lnePassword, self.btnOK)
        Login.setTabOrder(self.btnOK, self.btnCancel)

    def retranslateUi(self, Login):
        _translate = QtCore.QCoreApplication.translate
        Login.setWindowTitle(_translate("Login", "SSH Login"))
        self.labelUsername.setText(_translate("Login", "Username:"))
        self.labelPassword.setText(_translate("Login", "Password:"))
        self.btnCancel.setText(_translate("Login", "Cancel"))
        self.btnOK.setText(_translate("Login", "OK"))



import os
import sys

from setuptools import setup


# Place the directory containing _version_git on the path
for path, _, filenames in os.walk(os.path.dirname(os.path.abspath(__file__))):
    if "_version_git.py" in filenames:
        sys.path.append(path)
        break

from _version_git import __version__, get_cmdclass  # noqa

# Setup information is stored in setup.cfg but this function call
# is still necessary.
setup(cmdclass=get_cmdclass(), version=__version__)
